import { Integration } from './integration';
import { Agent } from './agent';
import { Logger, RegisteredLogger } from './logger';
import { AllTools, ToolApi } from './tools/types';
import { MastraEngine } from './engine';
import { MastraVector } from './vector';
export type SyncConfig<TIntegrations extends Integration[], MastraTools extends Record<string, ToolApi<TIntegrations, Record<string, any>, Record<string, any>>>, TParams> = (params: {
    tools: AllTools<TIntegrations, MastraTools>;
    params: TParams;
    engine: MastraEngine;
    vectors?: Record<string, MastraVector>;
    agents: Map<string, Agent<TIntegrations, MastraTools>>;
}) => Promise<void>;
export declare class Mastra<TIntegrations extends Integration[], MastraTools extends Record<string, ToolApi<TIntegrations, Record<string, any>, Record<string, any>>> = {}, TSyncs extends Record<string, SyncConfig<TIntegrations, MastraTools, any>> = Record<never, never>> {
    private engine?;
    private vectors?;
    private tools;
    private agents;
    private integrations;
    private logger;
    private syncs;
    constructor(config: {
        tools: MastraTools;
        syncs?: TSyncs;
        agents: Agent<TIntegrations, MastraTools>[];
        integrations: TIntegrations;
        engine?: MastraEngine;
        vectors?: Record<string, MastraVector>;
        logger?: Logger;
    });
    sync<K extends keyof TSyncs>(key: K, params: TSyncs[K] extends SyncConfig<any, any, infer P> ? P : never): Promise<void>;
    getAgent(name: string): Agent<TIntegrations, MastraTools, keyof (MastraTools extends {
        [x: string]: ToolApi<TIntegrations, Record<string, any>, Record<string, any>>;
    } ? MastraTools : {}) | keyof (TIntegrations extends Integration[] ? (import("./tools/types").IntegrationTools<TIntegrations[number]> extends infer T ? T extends import("./tools/types").IntegrationTools<TIntegrations[number]> ? T extends any ? (k: T) => void : never : never : never) extends (k: infer I) => void ? I : never : {})>;
    getIntegration(name: string): Integration;
    availableIntegrations(): {
        name: string;
        integration: Integration;
    }[];
    getTools(): AllTools<TIntegrations, MastraTools>;
    setLogger({ key, logger }: {
        key: RegisteredLogger;
        logger: Logger;
    }): void;
    getLogger(key: RegisteredLogger): Logger<import("./logger").BaseLogMessage> | undefined;
}
export * from './agent';
export * from './integration';
export * from './tools/types';
export * from './tools';
export * from './logger';
export * from './engine';
export * from './vector';
//# sourceMappingURL=index.d.ts.map